==> kubernetes-model-flowcontrol-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/FlowDistinguisherMethodBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class FlowDistinguisherMethodBuilder extends FlowDistinguisherMethodFluentImpl<FlowDistinguisherMethodBuilder> implements VisitableBuilder<FlowDistinguisherMethod,FlowDistinguisherMethodBuilder>{
  public FlowDistinguisherMethodBuilder() {
    this(false);
  }
  public FlowDistinguisherMethodBuilder(Boolean validationEnabled) {
    this(new FlowDistinguisherMethod(), validationEnabled);
  }
  public FlowDistinguisherMethodBuilder(FlowDistinguisherMethodFluent<?> fluent) {
    this(fluent, false);
  }
  public FlowDistinguisherMethodBuilder(FlowDistinguisherMethodFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new FlowDistinguisherMethod(), validationEnabled);
  }
  public FlowDistinguisherMethodBuilder(FlowDistinguisherMethodFluent<?> fluent,FlowDistinguisherMethod instance) {
    this(fluent, instance, false);
  }
  public FlowDistinguisherMethodBuilder(FlowDistinguisherMethodFluent<?> fluent,FlowDistinguisherMethod instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public FlowDistinguisherMethodBuilder(FlowDistinguisherMethod instance) {
    this(instance,false);
  }
  public FlowDistinguisherMethodBuilder(FlowDistinguisherMethod instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  FlowDistinguisherMethodFluent<?> fluent;
  Boolean validationEnabled;
  public FlowDistinguisherMethod build() {
    FlowDistinguisherMethod buildable = new FlowDistinguisherMethod(fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-flowcontrol-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/FlowDistinguisherMethodBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class FlowDistinguisherMethodBuilder extends FlowDistinguisherMethodFluent<FlowDistinguisherMethodBuilder> implements VisitableBuilder<FlowDistinguisherMethod,FlowDistinguisherMethodBuilder>{
  public FlowDistinguisherMethodBuilder() {
    this(false);
  }
  public FlowDistinguisherMethodBuilder(Boolean validationEnabled) {
    this(new FlowDistinguisherMethod(), validationEnabled);
  }
  public FlowDistinguisherMethodBuilder(FlowDistinguisherMethodFluent<?> fluent) {
    this(fluent, false);
  }
  public FlowDistinguisherMethodBuilder(FlowDistinguisherMethodFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new FlowDistinguisherMethod(), validationEnabled);
  }
  public FlowDistinguisherMethodBuilder(FlowDistinguisherMethodFluent<?> fluent,FlowDistinguisherMethod instance) {
    this(fluent, instance, false);
  }
  public FlowDistinguisherMethodBuilder(FlowDistinguisherMethodFluent<?> fluent,FlowDistinguisherMethod instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new FlowDistinguisherMethod());

    if (instance != null) {
      fluent.withType(instance.getType());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public FlowDistinguisherMethodBuilder(FlowDistinguisherMethod instance) {
    this(instance,false);
  }
  public FlowDistinguisherMethodBuilder(FlowDistinguisherMethod instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new FlowDistinguisherMethod());

    if (instance != null) {
      this.withType(instance.getType());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  FlowDistinguisherMethodFluent<?> fluent;
  Boolean validationEnabled;
  public FlowDistinguisherMethod build() {
    FlowDistinguisherMethod buildable = new FlowDistinguisherMethod(fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
